Webmention Rocks!

# Test #21

This post's Webmention endpoint has query string parameters. Your Webmention client must preserve the query string parameters, and not send them in the post body.
Friday April 15, 2016 8:06am -07:00

### Reacji

The emoji below show Reacji responses, created by people posting a comment linking to this post with an `in-reply-to` property, whose text is a single emoji character.

### Likes

The profile icons below are the author photos from people who have posted a "like" post on their site, where their post links to this post with the `like-of` property.

### Reposts

The profile icons below are the author photos from people who have posted a "repost" of this post on their site, where their post links to this post with the `repost-of` property.

### Bookmarks

The profile icons below are the author photos from people who have posted a bookmark of this post on their site, where their post links to this post with the `bookmark-of` property.

### Comments

The comments below are replies to this post, and marked up their link to the post with the `in-reply-to` property.

- Ryan Barrett snarfed.org

  ### Webmention Rocks!

  Monday, April 11, 2016 10:51am -07:00
- Tantek Çelik tantek.com
  @webmentionrocks tests 1-21 passing with @Falcon using @cassisjs and link-rel-parser-php! https://github.com/indieweb/link-rel-parser-php
  Friday, April 15, 2016 4:32am -07:00

### Mentions

The mentions below linked to this post, but did not include this post's URL as an `in-reply-to` property.

- Mike Taylor bear.im

  ### Testing Webmention.rocks

  Sunday, April 10, 2016 10:48pm +00:00
- http://mention-tech.appspot.com/static/logo.jpgmention.tech mention-tech.appspot.com

  ### Test page for pinging webmention.rocks from

  Monday, April 11, 2016 12:00am +00:00